@@ -17,31 +17,61 @@ sub new {
     return $self;
 }
 
+sub abstract {
+    return 'Parse regular expressions';
+}
+
+sub add_to_cleanup {
+    return [ qw{ cover_db } ];
+}
+
+sub author {
+    return 'Thomas R. Wyant, III F<wyant at cpan dot org>';
+}
+
 sub build_requires {
     return +{
 	'Test::More'	=> 0.88,	# Because of done_testing().
+	charnames	=> 0,
+	lib		=> 0,
     };
 }
 
+sub configure_requires {
+    return +{
+	'lib'	=> 0,
+	'strict'	=> 0,
+	'warnings'	=> 0,
+    };
+}
+
+sub dist_name {
+    return 'PPIx-Regexp';
+}
+
 sub distribution {
     my ( $self ) = @_;
     return $self->{distribution};
 }
 
+
+sub license {
+    return 'perl';
+}
+
 sub meta_merge {
     my ( undef, @extra ) = @_;
     return {
 	'meta-spec'	=> {
 	    version	=> 2,
 	},
-	no_index	=> {
-	    directory	=> [ qw{ inc t xt } ],
-	},
+	dynamic_config	=> 1,
 	resources	=> {
 	    bugtracker	=> {
-                web	=> 'https://github.com/trwyant/perl-PPIx-Regexp/issues',
-                mailto  => 'wyant@cpan.org',
-            },
+		web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp',
+		# web	=> 'https://github.com/trwyant/perl-PPIx-Regexp/issues',
+		mailto  => 'wyant@cpan.org',
+	    },
 	    license	=> 'http://dev.perl.org/licenses/',
 	    repository	=> {
 		type	=> 'git',
@@ -53,6 +83,21 @@ sub meta_merge {
     };
 }
 
+
+sub module_name {
+    return 'PPIx::Regexp';
+}
+
+sub no_index {
+    return +{
+      directory => [
+                     'inc',
+                     't',
+                     'xt',
+                   ],
+    };
+}
+
 sub provides {
     -d 'lib'
 	or return;
@@ -70,9 +115,11 @@ sub requires {
 ##  }
     return {
         'Carp'			=> 0,
+	'Encode'		=> 0,
         'Exporter'		=> 0,
         'List::Util'		=> 0,
 	'PPI::Document'		=> 1.117,	# for new( readonly => 1 )
+	'PPI::Dumper'		=> 1.117,
         'Scalar::Util'		=> 0,
 	'Task::Weaken'		=> 0,
 	'Text::Tabs'		=> 0,
@@ -88,6 +135,15 @@ sub requires_perl {
     return 5.006;
 }
 
+sub script_files {
+    return [
+    ];
+}
+
+sub version_from {
+    return 'lib/PPIx/Regexp.pm';
+}
+
 1;
 
 __END__
@@ -121,6 +177,19 @@ This class supports the following public methods:
 
 This method instantiates the class.
 
+=head2 abstract
+
+This method returns the distribution's abstract.
+
+=head2 add_to_cleanup
+
+This method returns a reference to an array of files to be added to the
+cleanup.
+
+=head2 author
+
+This method returns the name of the distribution author
+
 =head2 build_requires
 
  use YAML;
@@ -131,6 +200,20 @@ modules required to build the C<PPIx::Regexp> package, suitable for
 use in a F<Build.PL> C<build_requires> key, or a F<Makefile.PL>
 C<< {META_MERGE}->{build_requires} >> or C<BUILD_REQUIRES> key.
 
+=head2 configure_requires
+
+ use YAML;
+ print Dump( $meta->configure_requires() );
+
+This method returns a reference to a hash describing the modules
+required to configure the package, suitable for use in a F<Build.PL>
+C<configure_requires> key, or a F<Makefile.PL>
+C<< {META_MERGE}->{configure_requires} >> or C<CONFIGURE_REQUIRES> key.
+
+=head2 dist_name
+
+This method returns the distribution name.
+
 =head2 distribution
 
  if ( $meta->distribution() ) {
@@ -142,6 +225,10 @@ C<< {META_MERGE}->{build_requires} >> or C<BUILD_REQUIRES> key.
 This method returns the value of the environment variable
 C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
+=head2 license
+
+This method returns the distribution's license.
+
 =head2 meta_merge
 
  use YAML;
@@ -149,10 +236,21 @@ C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
 This method returns a reference to a hash describing the meta-data which
 has to be provided by making use of the builder's C<meta_merge>
-functionality. This includes the C<no_index> and C<resources> data.
+functionality. This includes the C<dynamic_config> and C<resources>
+data.
 
 Any arguments will be appended to the generated array.
 
+=head2 module_name
+
+This method returns the name of the module the distribution is based
+on.
+
+=head2 no_index
+
+This method returns the names of things which are not to be indexed
+by CPAN.
+
 =head2 provides
 
  use YAML;
@@ -182,6 +280,16 @@ may be added.
 
 This method returns the version of Perl required by the package.
 
+=head2 script_files
+
+This method returns a reference to an array containing the names of
+script files provided by this distribution. This array may be empty.
+
+=head2 version_from
+
+This method returns the name of the distribution file from which the
+distribution's version is to be derived.
+
 =head1 ATTRIBUTES
 
 This class has no public attributes.
@@ -197,8 +305,9 @@ information makes it into F<META.yml>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in electronic
-mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
