@@ -145,6 +145,17 @@ were introduced to deal with this complication.
 is parsed as the octal equivalent of C<\x{...}>. This is its meaning as
 of perl 5.13.2. Before 5.13.2 it was simply literal C<'o'> and so on.
 
+=item C<x{,3}>
+
+(with first count omitted) is allowed as a quantifier as of Perl 5.33.6.
+The previous parse made this all literals.
+
+=item C<x{ 0 , 3 }>
+
+(with spaces inside but adjacent to curly brackets, or around the comma
+if any) is allowed as a quantifier as of Perl 5.33.6. The previous parse
+made this all literals.
+
 =back
 
 There are very probably other examples of this. When they come to light
@@ -186,7 +197,7 @@ use PPIx::Regexp::Util qw{
 use Scalar::Util qw{ refaddr };
 use Text::Tabs ();
 
-our $VERSION = '0.076';
+our $VERSION = '0.079';
 
 =head2 new
 
@@ -454,7 +465,6 @@ any objects specified are removed from the cache.
 
 sub can_be_quantified { return; }
 
-
 =head2 capture_names
 
  foreach my $name ( $re->capture_names() ) {
@@ -568,7 +578,6 @@ sub extract_regexps {
     );
 }
 
-
 =head2 failures
 
  print "There were ", $re->failures(), " parse failures\n";
@@ -921,7 +930,9 @@ is again supported.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -929,7 +940,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
