@@ -54,7 +54,7 @@ use PPIx::Regexp::Constant qw{
     @CARP_NOT
 };
 
-our $VERSION = '0.074';
+our $VERSION = '0.079';
 
 =head2 accepts_perl
 
@@ -137,7 +137,6 @@ This method returns true if the element can be quantified.
 
 sub can_be_quantified { return 1; }
 
-
 =head2 class
 
 This method returns the class name of the element. It is the same as
@@ -318,6 +317,47 @@ For anything else this method returns a false (but defined) value.
 
 sub is_matcher { return 0; }
 
+# NOTE retracted this as a public method until I can investigate whether
+# the tokenizer can actually produce nested assertions.
+
+#=head2 in_assertion
+#
+#This method returns an array of assertions that contain the element,
+#most-local first. For the purpose of this method, a look-around
+#structure does not contain itself. If called in scalar context you get
+#the size of the array.
+#
+#This method was added in version 0.075_01.
+#
+#=cut
+
+sub __in_assertion {
+    my ( $self ) = @_;
+    my $elem = $self;
+    my @assertions;
+    while ( $elem = $elem->parent() ) {
+	$elem->isa( 'PPIx::Regexp::Structure::Assertion' )
+	    and push @assertions, $elem;
+    }
+    return @assertions;
+}
+
+# Convenience method that returns the number of look-behind
+# assertions that contain the current element. This is really only
+# here so it can be shared between PPIx::Regexp::Token::Quantifier
+# and PPIx::Regexp::Structure::Quantifier
+
+sub __in_look_behind {
+    my ( $self ) = @_;
+    my @look_behind;
+    foreach my $assertion ( $self->__in_assertion() ) {
+	$assertion->is_look_ahead()
+	    and next;
+	push @look_behind, $assertion;
+    }
+    return @look_behind;
+}
+
 =head2 in_regex_set
 
 This method returns a true value if the invocant is contained in an
@@ -1044,7 +1084,6 @@ sub __my_inx {
     return first { refaddr( $elem[$_] ) == $addr } 0 .. $#elem;
 }
 
-
 # Find our location and index among the parent's children. If not found,
 # just returns.
 
@@ -1148,7 +1187,9 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -1156,7 +1197,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
