@@ -58,12 +58,11 @@ use PPIx::Regexp::Constant qw{
 
 use constant KEEP_EXPLANATION	=> 'In s///, keep everything before the \\K';
 
-our $VERSION = '0.073';
+our $VERSION = '0.079';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
 
-
 my @braced_assertions = (
     [ qr< \\ [bB] [{] (?: g | gcb | wb | sb ) [}] >smx, '5.021009' ],
     [ qr< \\ [bB] [{] (?: lb ) [}] >smx, '5.023007' ],
@@ -203,7 +202,7 @@ sub __PPIX_TOKENIZER__regexp {
     # We special-case '\K' because it was retracted inside look-around
     # assertions in 5.31.3.
     if ( 'K' eq $next && __PACKAGE__ eq $make &&
-	$tokenizer->cookie( COOKIE_LOOKAROUND_ASSERTION ) ) {
+	$tokenizer->__cookie_exists( COOKIE_LOOKAROUND_ASSERTION ) ) {
 	return $tokenizer->make_token( 2, $make, {
 		perl_version_removed	=> '5.031003',
 		explanation		=> KEEP_EXPLANATION .
@@ -225,7 +224,9 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -233,7 +234,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
