@@ -48,7 +48,7 @@ use base qw{ PPIx::Regexp::Token };
 use PPIx::Regexp::Constant qw{ MINIMUM_PERL @CARP_NOT };
 use PPIx::Regexp::Util qw{ __ns_can };
 
-our $VERSION = '0.076';
+our $VERSION = '0.079';
 
 # Return true if the token can be quantified, and false otherwise
 sub can_be_quantified { return };
@@ -128,7 +128,6 @@ sub __make_group_type_matcher {
     return \%rslt;
 }
 
-
 =head2 __match_setup
 
  $class->__match_setup( $tokenizer );
@@ -151,7 +150,6 @@ sub __match_setup {
     return;
 }
 
-
 =head2 __setup_class
 
  $class->__setup_class( \%definition, \%opt );
@@ -286,7 +284,9 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -294,7 +294,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
