@@ -1,6 +1,4 @@
-# Cargo cult to try to prevent CPAN from indexing
-package
-PPIx::Regexp::Token::GroupType::Script_Run;
+package PPIx::Regexp::Token::GroupType::Script_Run;
 
 use 5.006;
 
@@ -11,28 +9,27 @@ use base qw{ PPIx::Regexp::Token::GroupType };
 
 use PPIx::Regexp::Constant qw{ @CARP_NOT };
 
-our $VERSION = '0.075';
+our $VERSION = '0.079';
 
-{
-    my $expl = 'All characters must be in same script';
+use constant EXPL => 'All characters must be in same script';
 
-    __PACKAGE__->__setup_class( {
-	    '+script_run:'	=> {
-		expl	=> $expl,
-		intro	=> '5.027008',
-		remov	=> '5.027009',
-	    },
-	    '*script_run:'	=> {
-		expl	=> $expl,
-		intro	=> '5.027009',
-	    },
-	    '*sr:'	=> {
-		expl	=> $expl,
-		intro	=> '5.027009',
-	    },
-	},
-    );
-}
+use constant DEF	=> {
+    '+script_run:'	=> {
+	expl	=> EXPL,
+	intro	=> '5.027008',
+	remov	=> '5.027009',
+    },
+    '*script_run:'	=> {
+	expl	=> EXPL,
+	intro	=> '5.027009',
+    },
+    '*sr:'	=> {
+	expl	=> EXPL,
+	intro	=> '5.027009',
+    },
+};
+
+__PACKAGE__->__setup_class();
 
 1;
 
@@ -74,7 +71,9 @@ superclass.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -82,7 +81,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2018-2020 by Thomas R. Wyant, III
+Copyright (C) 2018-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
